@@ -13,7 +13,6 @@ import (
 	"os"
 	"path/filepath"
 	"strconv"
-	"strings"
 	"syscall"
 	"testing"
 	"time"
@@ -382,7 +381,7 @@ func TestJobFailure(t *testing.T) {
 	executor.On("Cleanup").Once()
 
 	// Set up a failing a build script
-	thrownErr := errors.Join(&BuildError{Inner: errors.New("test error"), ExitCode: 1})
+	thrownErr := &BuildError{Inner: errors.New("test error"), ExitCode: 1}
 	executor.On("Shell").Return(&ShellScriptInfo{Shell: "script-shell"})
 	executor.On("Run", matchBuildStage(BuildStagePrepare)).Return(nil).Once()
 	executor.On("Run", mock.Anything).Return(thrownErr).Times(3)
@@ -502,11 +501,7 @@ func TestGetSourcesRunFailure(t *testing.T) {
 	executor.On("Run", matchBuildStage(BuildStageArchiveOnFailureCache)).Return(nil).Once()
 	executor.On("Run", matchBuildStage(BuildStageUploadOnFailureArtifacts)).Return(nil).Once()
 	executor.On("Run", matchBuildStage(BuildStageCleanup)).Return(nil).Once()
-	executor.On("Finish",
-		mock.MatchedBy(func(err error) bool {
-			return errors.Is(err, &BuildError{FailureReason: RunnerSystemFailure}) &&
-				strings.Contains(err.Error(), "build fail")
-		})).Once()
+	executor.On("Finish", errors.New("build fail")).Once()
 
 	build := registerExecutorWithSuccessfulBuild(t, provider, new(RunnerConfig))
 	build.Variables = append(build.Variables, JobVariable{Key: "GET_SOURCES_ATTEMPTS", Value: "3"})
@@ -529,11 +524,7 @@ func TestArtifactDownloadRunFailure(t *testing.T) {
 	executor.On("Run", matchBuildStage(BuildStageArchiveOnFailureCache)).Return(nil).Once()
 	executor.On("Run", matchBuildStage(BuildStageUploadOnFailureArtifacts)).Return(nil).Once()
 	executor.On("Run", matchBuildStage(BuildStageCleanup)).Return(nil).Once()
-	executor.On("Finish",
-		mock.MatchedBy(func(err error) bool {
-			return errors.Is(err, &BuildError{FailureReason: RunnerSystemFailure}) &&
-				strings.Contains(err.Error(), "build fail")
-		})).Once()
+	executor.On("Finish", errors.New("build fail")).Once()
 
 	build := registerExecutorWithSuccessfulBuild(t, provider, new(RunnerConfig))
 	build.Variables = append(build.Variables, JobVariable{Key: "ARTIFACT_DOWNLOAD_ATTEMPTS", Value: "3"})
@@ -558,11 +549,7 @@ func TestArtifactUploadRunFailure(t *testing.T) {
 	executor.On("Run", matchBuildStage(BuildStageArchiveOnSuccessCache)).Return(nil).Once()
 	executor.On("Run", matchBuildStage(BuildStageUploadOnSuccessArtifacts)).Return(errors.New("upload fail")).Once()
 	executor.On("Run", matchBuildStage(BuildStageCleanup)).Return(nil).Once()
-	executor.On("Finish",
-		mock.MatchedBy(func(err error) bool {
-			return errors.Is(err, &BuildError{FailureReason: RunnerSystemFailure}) &&
-				strings.Contains(err.Error(), "upload fail")
-		})).Once()
+	executor.On("Finish", errors.New("upload fail")).Once()
 
 	build := registerExecutorWithSuccessfulBuild(t, provider, new(RunnerConfig))
 	successfulBuild := build.JobResponse
@@ -618,11 +605,7 @@ func TestUploadArtifactsOnArchiveCacheFailure(t *testing.T) {
 	executor.On("Run", matchBuildStage(BuildStageArchiveOnSuccessCache)).Return(errors.New("cache failure")).Once()
 	executor.On("Run", matchBuildStage(BuildStageUploadOnSuccessArtifacts)).Return(nil).Once()
 	executor.On("Run", matchBuildStage(BuildStageCleanup)).Return(nil).Once()
-	executor.On("Finish",
-		mock.MatchedBy(func(err error) bool {
-			return errors.Is(err, &BuildError{FailureReason: RunnerSystemFailure}) &&
-				strings.Contains(err.Error(), "cache failure")
-		})).Once()
+	executor.On("Finish", errors.New("cache failure")).Once()
 
 	build := registerExecutorWithSuccessfulBuild(t, provider, new(RunnerConfig))
 	err := build.Run(&Config{}, &Trace{Writer: os.Stdout})
@@ -643,11 +626,7 @@ func TestRestoreCacheRunFailure(t *testing.T) {
 	executor.On("Run", matchBuildStage(BuildStageArchiveOnFailureCache)).Return(nil).Once()
 	executor.On("Run", matchBuildStage(BuildStageUploadOnFailureArtifacts)).Return(nil).Once()
 	executor.On("Run", matchBuildStage(BuildStageCleanup)).Return(nil).Once()
-	executor.On("Finish",
-		mock.MatchedBy(func(err error) bool {
-			return errors.Is(err, &BuildError{FailureReason: RunnerSystemFailure}) &&
-				strings.Contains(err.Error(), "build fail")
-		})).Once()
+	executor.On("Finish", errors.New("build fail")).Once()
 
 	build := registerExecutorWithSuccessfulBuild(t, provider, new(RunnerConfig))
 	build.Variables = append(build.Variables, JobVariable{Key: "RESTORE_CACHE_ATTEMPTS", Value: "3"})
@@ -669,10 +648,7 @@ func TestRunWrongAttempts(t *testing.T) {
 		Return(errors.New("number of attempts out of the range [1, 10] for stage: get_sources"))
 	executor.On(
 		"Finish",
-		mock.MatchedBy(func(err error) bool {
-			return errors.Is(err, &BuildError{FailureReason: RunnerSystemFailure}) &&
-				strings.Contains(err.Error(), "number of attempts out of the range [1, 10] for stage: get_sources")
-		}),
+		errors.New("number of attempts out of the range [1, 10] for stage: get_sources"),
 	)
 
 	build := registerExecutorWithSuccessfulBuild(t, provider, new(RunnerConfig))
@@ -2163,7 +2139,7 @@ func TestProjectUniqueName(t *testing.T) {
 				},
 				ProjectRunnerID: 0,
 			},
-			expectedName: "runner-zen8e6e-project-1234567890-concurrent-0",
+			expectedName: "runner-zen8e6en-project-1234567890-concurrent-0",
 		},
 		"project normal unique name": {
 			build: &Build{
@@ -2179,7 +2155,7 @@ func TestProjectUniqueName(t *testing.T) {
 				},
 				ProjectRunnerID: 0,
 			},
-			expectedName: "runner-xyzwabc--project-1234567890-concurrent-0",
+			expectedName: "runner-xyzwabc-i-project-1234567890-concurrent-0",
 		},
 	}
 
@@ -2209,7 +2185,7 @@ func TestProjectUniqueShortName(t *testing.T) {
 				},
 				ProjectRunnerID: 0,
 			},
-			expectedName: "runner-zen8e6e-1234567890-0-0",
+			expectedName: "runner-zen8e6en-1234567890-0-0",
 		},
 		"project normal unique name without build id": {
 			build: &Build{
@@ -2225,7 +2201,7 @@ func TestProjectUniqueShortName(t *testing.T) {
 				},
 				ProjectRunnerID: 0,
 			},
-			expectedName: "runner-xyzwabc--1234567890-0-0",
+			expectedName: "runner-xyzwabc-i-1234567890-0-0",
 		},
 		"project normal unique name with build id": {
 			build: &Build{
@@ -2242,7 +2218,7 @@ func TestProjectUniqueShortName(t *testing.T) {
 				},
 				ProjectRunnerID: 222222,
 			},
-			expectedName: "runner-xyzwabc--1234567890-222222-12345",
+			expectedName: "runner-xyzwabc-i-1234567890-222222-12345",
 		},
 	}
 
@@ -2702,8 +2678,8 @@ func Test_expandContainerOptions(t *testing.T) {
 }
 
 func TestPrintPolicyOptions(t *testing.T) {
-	var falseValue = false
-	var trueValue = true
+	falseValue := false
+	trueValue := true
 	testCases := []struct {
 		desc          string
 		policyOptions PolicyOptions
