@@ -424,7 +424,7 @@ func (e *executor) createService(
 	linkNames []string,
 ) (*types.Container, error) {
 	if service == "" {
-		return nil, common.MakeBuildError("invalid service image name: %s", definition.Name).WithFailureReason(common.ConfigurationError)
+		return nil, common.MakeBuildError("invalid service image name: %s", definition.Name)
 	}
 
 	if e.volumesManager == nil {
@@ -978,7 +978,7 @@ func (e *executor) startAndWatchContainer(ctx context.Context, id string, input
 	if id == e.buildContainerID && e.Build.UseNativeSteps() {
 		request, err := steps.NewRequest(e.Build)
 		if err != nil {
-			return common.MakeBuildError("creating steps request: %w", err).WithFailureReason(common.ConfigurationError)
+			return common.MakeBuildError("creating steps request: %w", err)
 		}
 		dockerExec = exec.NewStepsDocker(e.Context, e.dockerConn, e.waiter, e.Build.Log(), request)
 	}
@@ -1099,6 +1099,13 @@ func (e *executor) expandImageName(imageName string, allowedInternalImages []str
 		return "", errors.New("no Docker image specified to run the build in")
 	}
 
+	e.BuildLogger.
+		WithFields(logrus.Fields{
+			"executor": "docker",
+			"image":    defaultDockerImage,
+		}).
+		Infoln("Using default image")
+
 	return defaultDockerImage, nil
 }
 
@@ -1425,7 +1432,7 @@ func (e *executor) prepareHelperImage() (helperimage.Info, error) {
 
 func (e *executor) prepareBuildsDir(options common.ExecutorPrepareOptions) error {
 	if e.volumeParser == nil {
-		return common.MakeBuildError("missing volume parser").WithFailureReason(common.RunnerSystemFailure)
+		return common.MakeBuildError("missing volume parser")
 	}
 
 	isHostMounted, err := volumes.IsHostMountedVolume(e.volumeParser, e.RootDir(), options.Config.Docker.Volumes...)
